@@ -66,7 +66,7 @@ class ListDives(object):
         """
         parser.add_argument('input',
                 nargs='+',
-                help='UDDF file with dive profiles')
+                help='UDDF files with dive data')
 
 
     def __call__(self, args):
@@ -79,8 +79,8 @@ class ListDives(object):
             dives = kl.find_dives([fin])
             print('{}:'.format(fin))
             for i, d in enumerate(kl.list_dives(dives), 1):
-                print('{:5}: {:>9} {:>9} ({:>5}) {:>9} {:>9}'.format(i,
-                    d[0], d[1], d[2] or ' --- ', d[3], d[4]))
+                print('{:5}: {:>4} {:>9} {:>9} ({:>5}) {:>9} {:>9}'.format(i,
+                    d[0] or ' -- ', d[1], d[2], d[3] or ' --- ', d[4], d[5]))
 
 
 
@@ -152,7 +152,7 @@ class CopyDive(object):
         import kenozooid.logbook as kl
 
         r, f = args.input
-        kl.copy_dives(f, r, args.logbook)
+        kl.copy_dives(f, r, args.dives, args.logbook)
 
 
 
@@ -238,7 +238,7 @@ class ListDiveSites(object):
                     ' site name')
         parser.add_argument('input',
                 nargs='+',
-                help='UDDF file with dive sites')
+                help='UDDF files with dive sites')
 
 
     def __call__(self, args):
@@ -439,7 +439,7 @@ class DelBuddy(object):
 
 
 @inject(CLIModule, name='upgrade')
-class DelBuddy(object):
+class UpgradeFile(object):
     """
     Upgrade a file to newer version of UDDF.
     """
@@ -473,6 +473,38 @@ class DelBuddy(object):
 
 
 
+@inject(CLIModule, name='dive enum')
+class EnumDives(object):
+    """
+    Enumerate dives.
+    """
+    description = 'enumerate dives'
+
+    @classmethod
+    def add_arguments(self, parser):
+        """
+        Add options for dive enumeration.
+        """
+        parser.add_argument('-ns', '---dive-total-number',
+                metavar='dive_total_number',
+                nargs='?',
+                type=int,
+                default=1,
+                help='start of total dive number')
+        parser.add_argument('input',
+                nargs='+',
+                help='UDDF files with dive data')
+
+
+    def __call__(self, args):
+        """
+        Execute command to enumerate dives.
+        """
+        import kenozooid.logbook as kl
+        kl.enum_dives(args.input, args.dive_total_number)
+
+
+
 def _name_parse(name):
     """
     Parse name data from a string. The name string is in simplified BibTeX
